# pylindas

## About

`pylindas` is a python package for building and publishing linked data cubes according to the [cube.link](https://cube.link) schema. This schema is used to transform tabular data into [RDF](https://www.w3.org/RDF/). `pylindas` is an alternative to the [Cube-Creator](https://cube-creator.lindas.admin.ch). Whereas the Cube-Creator is a [GUI](https://en.wikipedia.org/wiki/Graphical_user_interface) tool, `pylindas` is more suited to fit into a pipeline workflow to create RDF. Currently this project is heavily linked to [LINDAS](https://lindas.admin.ch) the Swiss Federal Linked Data Service.

## Documentation

- [Installation](docs/installation.md)
- [Contributing](docs/contributing.md)
- [Basic functionality](docs/functionality.md)
- [Command line usage](docs/cli.md)
- [Examples](docs/examples.md)
- [URIs](docs/uris.md)
- [Concepts](docs/concepts.md)
- [Shared Dimensions](docs/sd.md)
